unit MainTask;

interface

uses Classes, Controls, Forms, StdCtrls, Spin;

type
  TMainTaskForm = class(TForm)
    TasksLB: TListBox;
    TaskAddBtn: TButton;
    TaskEditBtn: TButton;
    TaskDeleteBtn: TButton;
    Label4: TLabel;
    ServerEd: TEdit;
    GroupBox2: TGroupBox;
    DSEd: TEdit;
    Label3: TLabel;
    StoreBtn: TButton;
    Label5: TLabel;
    Label1: TLabel;
    Label2: TLabel;
    ConnectBtn: TButton;
    CheckBox1: TCheckBox;
    ProxyEd: TEdit;
    PortEd: TSpinEdit;
    UserNameEd: TEdit;
    PasswordEd: TEdit;
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ConnectBtnClick(Sender: TObject);
    procedure TasksLBClick(Sender: TObject);
    procedure TaskAddBtnClick(Sender: TObject);
    procedure TaskEditBtnClick(Sender: TObject);
    procedure TaskDeleteBtnClick(Sender: TObject);
    procedure StoreBtnClick(Sender: TObject);
    procedure CheckBox1Click(Sender: TObject);
  private
    procedure UpdateTasks;
    procedure UpdateTaskButtons;
  end;

var
  MainTaskForm: TMainTaskForm;

implementation

uses SysUtils, EditTask, TaskSyncML, SyncMLBase;

{$R *.dfm}

var
  SMLTasks: TSMLTasks;

procedure TMainTaskForm.FormCreate(Sender: TObject);
begin
  SMLTasks := TSMLTasks.Create;
//  SMLTasks.LogFileName := 'TaskSyncML.log';
end;

procedure TMainTaskForm.FormDestroy(Sender: TObject);
begin
  SMLTasks.Free;
end;

procedure TMainTaskForm.UpdateTasks;
var
  I: Integer;
begin
  TasksLB.Clear;
  Screen.Cursor := crHourGlass;
  try
    for I := 0 to SMLTasks.TaskCount - 1 do
      with SMLTasks.Tasks[I] do
        if LocalItemState <> isDeleted then
          TasksLB.Items.Add(Title);
  finally
    Screen.Cursor := crDefault;
  end;
  UpdateTaskButtons;
end;

procedure TMainTaskForm.UpdateTaskButtons;
begin
  TaskEditBtn.Enabled := TasksLB.ItemIndex >= 0;
  TaskDeleteBtn.Enabled := TasksLB.ItemIndex >= 0;
end;

procedure TMainTaskForm.ConnectBtnClick(Sender: TObject);
begin
  TaskAddBtn.Enabled := False;
  TasksLB.Items.Clear;
  Application.ProcessMessages;
  if not CheckBox1.Checked then
  begin
    SMLTasks.ProxyServer := ProxyEd.Text;
    SMLTasks.ProxyPort := PortEd.Value;
  end
  else
  begin
    SMLTasks.ProxyServer := '';
    SMLTasks.ProxyPort := 0;
  end;
  SMLTasks.BaseURL := ServerEd.Text;
  SMLTasks.UserName := UserNameEd.Text;
  SMLTasks.Password := PasswordEd.Text;
  SMLTasks.DataSource := DSEd.Text;
  SMLTasks.Load;
  TaskAddBtn.Enabled := True;
  UpdateTasks;
  ConnectBtn.Caption := 'Refresh';
  StoreBtn.Enabled := False;
  UpdateTaskButtons;
end;

procedure TMainTaskForm.TasksLBClick(Sender: TObject);
begin
  UpdateTaskButtons;
end;

procedure TMainTaskForm.TaskAddBtnClick(Sender: TObject);
begin
  EditTaskForm.Task := SMLTasks.NewTask;
  if EditTaskForm.ShowModal = mrOK then
  begin
    TasksLB.Items.Add(EditTaskForm.Task.Title);
    UpdateTaskButtons;
    StoreBtn.Enabled := True;
  end
  else
    SMLTasks.DeleteTask(SMLTasks.TaskCount - 1);
end;

procedure TMainTaskForm.TaskEditBtnClick(Sender: TObject);
begin
  EditTaskForm.Task := SMLTasks.Tasks[TasksLB.ItemIndex];
  if EditTaskForm.ShowModal = mrOK then
  begin
    TasksLB.Items[TasksLB.ItemIndex] := EditTaskForm.Task.Title;
    StoreBtn.Enabled := True;
  end;
end;

procedure TMainTaskForm.TaskDeleteBtnClick(Sender: TObject);
begin
  SMLTasks.DeleteTask(TasksLB.ItemIndex);
  TasksLB.Items.Delete(TasksLB.ItemIndex);
  UpdateTaskButtons;
  StoreBtn.Enabled := True;
end;

procedure TMainTaskForm.StoreBtnClick(Sender: TObject);
begin
  SMLTasks.Store;
  UpdateTasks;
  StoreBtn.Enabled := false;
end;

procedure TMainTaskForm.CheckBox1Click(Sender: TObject);
begin
  ProxyEd.Enabled := CheckBox1.Checked;
  PortEd.Enabled := ProxyEd.Enabled;
end;

end.

